@@ -1,5 +1,5 @@
 def validate_bool(my_bool):
     if isinstance(my_bool, bool):
-        return True
+        return
     if my_bool.lower() not in ("true", "false"):
         raise ValueError
