@@ -4,5 +4,5 @@ import os
 
 def validate_filepath(fp):
     if not os.path.isfile(fp):
-        raise argparse.ArgumentTypeError(f"have to be file")
+        raise argparse.ArgumentTypeError(f"has to be file")
     return fp
